## NodePasta
Want to implement a visual scripting system into your program but don't want to write it yourself? NodePasta has got you covered.

NodePasta is a node based-visual scripting framework that lets you define your own nodes and it will take care of the rest.
A NodePasta NodeGraph is UI agnostic, meaning you can load and run graphs without needing a UI implented, but the real magic comes from letting your users
develop their own graphs. NodePasta comes pre-packaged with a editor UI written for TKInter, that you can embed into your application.

### TODO
- Port Default/Const Values
- Subgraph nodes
- Variable length inputs
    
- Documentation
    - Node Developer Docs
    - UI Developer Docs
    - TK UI Tutorials

### Stretch Goals
- TK
  - Forked Links
  - Live Graph Execution
  - Allow Key rebinds
  - Color configurations
  - Grab multiple nodes to move